@@ -1,11 +1,20 @@
+# 拓展插件基类
 class Extension:
     def __init__(self, ext_config, custom_config):
         self._ext_config = ext_config
         self._custom_config = custom_config
 
+    async def run(self, arg_dict) -> dict:
+        """ 插件运行 """
+        raise NotImplementedError
+
     async def call(self, arg_dict) -> dict:
         """ 调用插件 """
-        raise NotImplementedError
+        self._call_time -= 1
+        if self._call_time < 0:
+            return {}
+        else:
+            return await self.run(arg_dict)
 
     def generate_description(self, chat_history_text='') -> str:
         """ 生成插件描述 """
@@ -28,7 +37,13 @@ class Extension:
         """ 获取插件自定义配置 """
         return self._custom_config
 
+    def reset_call_times(self):
+        """ 重置调用次数 """
+        self._call_time = self._ext_config.get('max_call_times_per_msg', 99)
+
 if __name__ == '__main__':
     import os, shutil
     # 复制 Extension.py 到 ../extensions/ 目录下
-    shutil.copyfile(os.path.join(os.path.dirname(__file__), 'Extension.py'), os.path.join(os.path.dirname(__file__), '..', 'extensions', 'Extension.py'))
\ No newline at end of file
+    shutil.copyfile(os.path.join(os.path.dirname(__file__), 'Extension.py'), os.path.join(os.path.dirname(__file__), '..', 'extensions', 'Extension.py'))
+    # 复制 Extension.py 到 ../share_exts/ 目录下
+    shutil.copyfile(os.path.join(os.path.dirname(__file__), 'Extension.py'), os.path.join(os.path.dirname(__file__), '..', 'share_exts', 'Extension.py'))
