@@ -14,6 +14,7 @@ import pickle
 import random
 import importlib
 import traceback
+import asyncio
 
 from .config import *
 global_config = get_driver().config
@@ -62,13 +63,13 @@ class Chat:
             self.chat_presets['chat_history'].pop(0)
 
         if len(self.chat_presets['chat_history']) > config['CHAT_MEMORY_MAX_LENGTH'] and require_summary: # 只有在需要时才进行总结 避免不必要的token消耗
-            prev_summarized = f"上次的对话摘要:{self.chat_presets['chat_summarized']}\n\n" \
+            prev_summarized = f"Summary of last conversation:{self.chat_presets['chat_summarized']}\n\n" \
                 if self.chat_presets.get('chat_summarized') else ''
             history_str = '\n'.join(self.chat_presets['chat_history'])
             prompt = (  # 以机器人的视角总结对话历史
-                f"{prev_summarized}对话记录:\n"
+                f"{prev_summarized}[Chat]\n"
                 f"{history_str}"
-                f"\n\n{self.chat_presets['bot_self_introl']}\n从{self.chat_presets['bot_name']}的视角用一段话总结以上聊天并尽可能多地记录下对话中的重要信息:"
+                f"\n\n{self.chat_presets['bot_self_introl']}\nSummarize the chat in one paragraph from the perspective of '{self.chat_presets['bot_name']}' and record as much important information as possible from the conversation:"
             )
             if config.get('__DEBUG__'): logger.info(f"生成对话历史摘要prompt: {prompt}")
             res, success = await tg.get_response(prompt, type='summarize')  # 生成新的对话历史摘要
@@ -90,13 +91,13 @@ class Chat:
         logger.info(f"添加对话历史行: {messageunit}  |  当前对话历史行数: {len(global_preset_userdata[self.preset_key][userid]['chat_history'])}")
         # 保证对话历史不超过最大长度
         if len(global_preset_userdata[self.preset_key][userid]['chat_history']) > config['USER_MEMORY_SUMMARY_THRESHOLD'] and require_summary:
-            prev_summarized = f"上次的印象:{global_preset_userdata[self.preset_key][userid].get('chat_summarized')}\n\n" \
+            prev_summarized = f"Last impression:{global_preset_userdata[self.preset_key][userid].get('chat_summarized')}\n\n" \
                 if global_preset_userdata[self.preset_key][userid].get('chat_summarized') else ''
             history_str = '\n'.join(global_preset_userdata[self.preset_key][userid]['chat_history'])
             prompt = (   # 以机器人的视角总结对话
-                f"{prev_summarized}对话记录:\n"
+                f"{prev_summarized}[Chat]\n"
                 f"{history_str}"
-                f"\n\n{self.chat_presets['bot_self_introl']}\n从{self.chat_presets['bot_name']}的视角更新对{username}的印象:"
+                f"\n\n{self.chat_presets['bot_self_introl']}\nUpdate {username} impressions from the perspective of {self.chat_presets['bot_name']}:"
             )
             if config.get('__DEBUG__'): logger.info(f"生成对话历史摘要prompt: {prompt}")
             res, success = await tg.get_response(prompt, type='summarize')  # 生成新的对话历史摘要
@@ -151,24 +152,30 @@ class Chat:
 
         # 拓展描述
         ext_descs = ''.join([global_extensions[ek].generate_description(chat_history) for ek in global_extensions.keys()])
-
+        # 拓展使用示例
         extension_text = (
-            '[Speaking options]\n'
-            'Speeking options can be used in the following strict format. Multiple options can be used in one reply.\n'
+            '[Speak options]\n'
+            'importrant: The speak option is available if and only if in the following strict format. Multiple options can be used in one reply.\n'
             # '- Random > min:a; max:b (send a random number between a and b)'
-            f'{ext_descs}'
+            f'{ext_descs}\n'
             'Use format: /#extension_name&param1&param2#/ (parameters are separated by &)\n\n'
             # 'example use in reply: i will send 2 random number /#Random&0&5#/ /#Random&5&10#/\n\n'    # 拓展使用示例 /#拓展名&参数1&参数2#/，参数之间用&分隔
-        ) if config.get('NG_ENABLE_EXT') else ''
+        ) if config.get('NG_ENABLE_EXT') and ext_descs else (
+            '[Speak options]\n'
+            'No extension is currently available. Do not use the extension function like /#extension_name&param1&param2#/.\n\n'
+        )
+
+        # 发言提示
+        say_prompt = "(Multiple segment replies are separated by '*;', single quotes are not included)" if config.get('NG_ENABLE_MSG_SPLIT') else ''
 
         # 返回对话 prompt 模板
         return (    # 返回对话 prompt 模板
             f"{self.chat_presets['bot_self_introl']}"
             f"\n{summary}\n{impression_text}"
-            # f"以下是与 \"{self.chat_presets['bot_name']}\" 的对话:"
             f"{extension_text}"
+            # f"以下是与 \"{self.chat_presets['bot_name']}\" 的对话:"
             f"[Chat - current time: {time.strftime('%Y-%m-%d %H:%M:%S')}]\n"
-            f"\n{chat_history}\n{self.chat_presets['bot_name']}(Multiple segment replies are separated by Spaces):"
+            f"\n{chat_history}\n{self.chat_presets['bot_name']}{say_prompt}:"
         )
 
     # 获取当前对话bot的名称
@@ -179,10 +186,14 @@ class Chat:
     def get_chat_preset_key(self) -> str:
         return self.preset_key
 
-    # 开关对话
+    # 开关当前会话
     def toggle_chat(self, enabled:bool=True) -> None:
         self.is_enable = enabled
 
+    # 获取当前会话描述
+    def generate_description(self):
+        return f"[{'启用' if self.is_enable else '禁用'}] 会话: {self.chat_key} 预设: {self.get_chat_bot_name()}\n"
+
 """ ======== 读取历史记忆数据 ======== """
 # 检测历史数据pickle文件是否存在 不存在则初始化 存在则读取
 if os.path.exists(global_data_path):
@@ -200,7 +211,7 @@ if os.path.exists(global_data_path):
 else:   # 如果不存在历史数据json文件，则初始化
     # 检测目录是否存在 不存在则创建
     if not os.path.exists(config['NG_DATA_PATH']):
-        os.makedirs(config['NG_DATA_PATH'])
+        os.makedirs(config['NG_DATA_PATH'], exist_ok=True)
 
     # 创建用于存储所有人格预设的字典
     presets_dict:dict = config['PRESETS']
@@ -242,7 +253,7 @@ if config.get('NG_ENABLE_EXT'):
 
     # 在当前文件夹下建立一个ext_cache文件夹 用于暂存拓展模块的.py文件以便于动态导入
     if not os.path.exists('ext_cache'):
-        os.makedirs('ext_cache')
+        os.makedirs('ext_cache', exist_ok=True)
     # 删除ext_cache文件夹下的所有文件和文件夹
     for file in os.listdir('ext_cache'):
         file_path = os.path.join('ext_cache', file)
@@ -277,7 +288,7 @@ if config.get('NG_ENABLE_EXT'):
                 time.sleep(0.3)  # 等待文件导入完成
 
                 ext = CustomExtension(tmpExt.get("EXT_CONFIG", {}))  # 加载拓展模块并实例化
-                global_extensions[ext.get_config().get('name')] = ext  # 将拓展模块添加到全局拓展模块字典中
+                global_extensions[ext.get_config().get('name').lower()] = ext  # 将拓展模块添加到全局拓展模块字典中
                 logger.info(f"加载拓展模块 {ext} 成功")
             except Exception as e:
                 logger.error(f"加载拓展模块 \"{tmpExt.get('EXT_NAME')}\" 失败 | 原因: {e}")
@@ -288,6 +299,11 @@ if config.get('NG_ENABLE_EXT'):
 matcher:Matcher = on_message(priority=config['NG_MSG_PRIORITY'], block=config['NG_BLOCK_OTHERS'])
 @matcher.handle()
 async def handler(event: Event) -> None:
+    # 判断用户账号是否被屏蔽
+    if event.get_user_id() in config['FORBIDDEN_USERS']:
+        logger.info(f"用户 {event.get_user_id()} 被屏蔽，拒绝处理消息")
+        return
+
     sta = time.time()
     sender_name = event.dict().get('sender', {}).get('nickname', '未知')
     resTmplate = (  # 测试用，获取消息的相关信息
@@ -337,13 +353,13 @@ async def handler(event: Event) -> None:
     wake_up = False
     # 检测是否包含违禁词
     for w in config['WORD_FOR_FORBIDDEN']:
-        if w in event.get_plaintext():
+        if str(w) in event.get_plaintext():
             logger.info(f"检测到违禁词 {w}，拒绝处理...")
             return
 
     # 唤醒词检测
     for w in config['WORD_FOR_WAKE_UP']:
-        if w in event.get_plaintext():
+        if str(w) in event.get_plaintext():
             wake_up = True
             break
 
@@ -400,16 +416,24 @@ async def handler(event: Event) -> None:
     # 用于存储最终回复顺序内容的列表
     reply_list = []
 
-    # 按照拓展调用的格式，将所有非调用部分去除后再将剩余信息放入回复列表
+    # 按照拓展调用的格式，将所有非调用部分去除后再将剩余信息切分放入回复列表
     pattern = '/#.*?#/'
     reply_list = re.sub(pattern, '', raw_res).split()
+    # 对分割后的对话再次根据 '*;' 进行分割，表示对话结果中的分句，处理结果为列表，其中每个元素为一句话
+    if config.get('NG_ENABLE_MSG_SPLIT'):
+        reply_list = [reply.strip() for reply in re.split(r'\*;', ' '.join(reply_list)) if reply.strip()]
+
     if config.get('__DEBUG__'): logger.info("分割对话结果: " + str(reply_list))
 
+    # 重置所有拓展调用次数
+    for ext_name in global_extensions.keys():
+        global_extensions[ext_name].reset_call_times()
+
     # 分割对话结果提取出所有 "/#拓展名&参数1&参数2#/" 格式的拓展调用指令 参数之间用&分隔
     ext_calls = re.findall(r"/#(.+?)#/", raw_res)
     for ext_call_str in ext_calls:  # 遍历所有拓展调用指令
         ext_name, *ext_args = ext_call_str.split('&')
-        if ext_name in global_extensions.keys():
+        if ext_name.lower() in global_extensions.keys():
             # 提取出拓展调用指令中的参数为字典
             ext_args_dict:dict = {}
             # 按照参数顺序依次提取参数值
@@ -431,8 +455,12 @@ async def handler(event: Event) -> None:
                 logger.error(f"调用拓展 {ext_name} 时发生错误: {e}")
                 if config.get('__DEBUG__'): logger.error(f"[拓展 {ext_name}] 错误详情: {traceback.format_exc()}")
                 ext_res = None
+                # 将错误的调用指令从原始回复中去除，避免bot从上下文中学习到错误的信息
+                raw_res = raw_res.replace(f"/#{ext_call_str}#/", '')
         else:
             logger.error(f"未找到拓展 {ext_name}，跳过调用...")
+            # 将错误的调用指令从原始回复中去除，避免bot从上下文中学习到错误的信息
+            raw_res = raw_res.replace(f"/#{ext_call_str}#/", '')
 
     if config.get('__DEBUG__'): logger.info(f"回复序列内容: {reply_list}")
 
@@ -455,8 +483,9 @@ async def handler(event: Event) -> None:
                 res_times -= 1
                 if res_times < 1:  # 如果回复次数超过限制，则跳出循环
                     break
+        await asyncio.sleep(1.5)  # 每条回复之间间隔1.5秒
 
-    cost_token = tg.cal_token_count(prompt_template + raw_res)      # 计算对话结果的 token 数量
+    cost_token = tg.cal_token_count(prompt_template + raw_res)  # 计算对话结果的 token 数量
 
     while time.time() - sta_time < 1.5:   # 限制对话响应时间
         time.sleep(0.1)
@@ -474,6 +503,10 @@ identity:Matcher = on_command("identity", aliases={"人格设定", "人格", "rg
 @identity.handle()
 async def _(event: Event, arg: Message = CommandArg()):
     is_progress = False
+    # 判断是否是禁止使用的用户
+    if event.get_user_id() in config.get('FORBIDDEN_USERS', []):
+        await identity.finish(f"您的账号({event.get_user_id()})已被禁用，请联系管理员。")
+
     # 判断群聊/私聊
     if isinstance(event, GroupMessageEvent):
         chat_key = 'group_' + event.get_session_id().split("_")[1]
@@ -523,13 +556,14 @@ async def _(event: Event, arg: Message = CommandArg()):
             f"+ 删除预设(管理): rg 删除 <预设名>\n"
             f"+ 锁定预设(管理): rg 锁定 <预设名>\n"
             f"+ 解锁预设(管理): rg 解锁 <预设名>\n"
-            f"+ 开启会话(管理): rg <开启/on>\n"
-            f"+ 停止会话(管理): rg <关闭/off>\n"
-            f"+ 重置会话(管理): rg <重置/reset>\n"
+            f"+ 开启会话(管理): rg <开启/on> <-all?>\n"
+            f"+ 停止会话(管理): rg <关闭/off> <-all?>\n"
+            f"+ 重置会话(管理): rg <重置/reset> <-all?>\n"
+            f"+ 拓展信息(管理): rg <拓展/ext>\n"
             f"Tip: <人格信息> 是一段第三人称的人设说明(不超过200字, 不包含空格)\n"
         ))
 
-    elif (cmd.split(' ')[0] == "设定" or cmd.split(' ')[0] == "set") and len(cmd.split(' ')) == 2:
+    elif (cmd.split(' ')[0] in ["设定", "set"]) and len(cmd.split(' ')) >= 2:
         target_preset_key = cmd.split(' ')[1]
         if target_preset_key not in presets_dict:
             # 如果预设不存在，进行逐一进行字符匹配，选择最相似的预设
@@ -538,18 +572,23 @@ async def _(event: Event, arg: Message = CommandArg()):
                 await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
             else:
                 target_preset_key = target_preset_key[0]
-                await identity.send(f"预设不存在! 已为您匹配并应用最相似的预设: {target_preset_key} v(￣▽￣)v")
+                await identity.send(f"预设不存在! 已为您匹配最相似的预设: {target_preset_key} v(￣▽￣)v")
 
-        if chat_key in chat_dict:
-            chat:Chat = chat_dict[chat_key]
-            chat.change_presettings(target_preset_key)
+        if len(cmd.split(' ')) >= 2 and cmd.split(' ')[2] == '-all':
+            for chat_key in chat_dict.keys():
+                chat_dict[chat_key].change_presettings(target_preset_key)
+            await identity.send(f"应用预设: {target_preset_key} (￣▽￣)-ok! (所有会话)")
         else:
-            chat:Chat = Chat(chat_key, target_preset_key)
-            chat_dict[chat_key] = chat
+            if chat_key in chat_dict:
+                chat:Chat = chat_dict[chat_key]
+                chat.change_presettings(target_preset_key)
+            else:
+                chat:Chat = Chat(chat_key, target_preset_key)
+                chat_dict[chat_key] = chat
+            await identity.send(f"应用预设: {target_preset_key} (￣▽￣)-ok!")
         is_progress = True
-        await identity.finish(f"应用预设: {target_preset_key} (￣▽￣)-ok!")
 
-    elif (cmd.split(' ')[0] in ["查询", "query"]) and len(cmd.split(' ')) == 2:
+    elif (cmd.split(' ')[0] in ["查询", "query"]) and len(cmd.split(' ')) >= 2:
         target_preset_key = cmd.split(' ')[1]
         if target_preset_key not in presets_dict:
             # 如果预设不存在，进行逐一进行字符匹配，选择最相似的预设
@@ -679,8 +718,13 @@ async def _(event: Event, arg: Message = CommandArg()):
         elif debug_cmd == 'run':
             await identity.finish(str(exec(cmd.split(' ', 2)[2])))
 
-    elif cmd.split(' ')[0] == "test":
-        ...
+    elif cmd in ["会话", "chats"]:
+        if str(event.user_id) not in config['ADMIN_USERID']:
+            await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
+        chat_info = ''
+        for chat in chat_dict.values():
+            chat_info += f"+ {chat.generate_description()}"
+        await identity.finish((f"当前已加载的会话:\n{chat_info}"))
 
     else:
         await identity.finish("输入的命令好像有点问题呢... 请检查下再试试吧！ ╮(>_<)╭")
@@ -699,14 +743,14 @@ async def _(event: Event, arg: Message = CommandArg()):
 # 保存数据到本地
 def save_data():
     global last_save_data_time
-    if time.time() - last_save_data_time < 10:  # 如果距离上次保存时间不足300秒，则不保存
+    if time.time() - last_save_data_time < 60:  # 如果距离上次保存时间不足60秒则不保存
         return
     global_data['PRESETS'] = presets_dict
     global_data['PRESET_USERDATA'] = global_preset_userdata
     global_data['CHAT_DICT'] = chat_dict
     # 检测目录是否存在 不存在则创建
     if not os.path.exists(config['NG_DATA_PATH']):
-        os.makedirs(config['NG_DATA_PATH'])
+        os.makedirs(config['NG_DATA_PATH'], exist_ok=True)
     # 保存到pickle文件
     with open(global_data_path, 'wb') as f:
         pickle.dump(global_data, f)
